<?php
namespace App\Controller\Admin;
use App\Controller\Admin\Component\ImgComponent;

use App\Controller\Admin\AppController;
use Cake\Event\Event;
use Cake\ORM\TableRegistry;
use Cake\Core\Configure;
use Cake\I18n\Time;
use Cake\View\Helper\TimeHelper;
use Cake\Datasource\ConnectionManager;

use Cake\View\Helper\PaginatorHelper;
use Cake\Network\Exception\NotFoundException;
use Cake\View\Exception\MissingTemplateException;
/******************************************************************************
*File Name:	 Controller
*Creation Date: [11-02-2016]
*Modification Date: [11-02-2016]
*Author: [Raushan Suri]
*Author: [Modified By Raushan Suri]
*Description: [This controller consist of function related to Department.]
******************************************************************************/
class PurchasesController extends AppController
{

    public function beforeFilter(Event $event)
    {
        parent::beforeFilter($event);
        $this->Auth->allow(['showprofile']);
    }

    
    /********************************************************************************
	Function Name: index
	*Type: Public function used as action of the controller
	*Input: No input
	*Author: Raushan Suri
	*Modified By: Raushan Suri
	*Output: Function to view all member list and search.
	*********************************************************************************/
    public function index($id=null)
    {
        $layoutTitle = 'QuiQR :: Manage Purchase';
        $this->set(compact('layoutTitle'));
        $this->viewBuilder()->layout('Admin/admin');
        $limit = 30;//Configure::read('App.adminPageLimit');
        $this->loadModel('Users');
		$DList = $this->Users->find('list', ['keyField' => 'id', 'valueField' => ['fullName', 'email']])
						->where(['Users.role'=>'Driver'])
                        ->order(['Users.fullName'=>'ASC'])->toArray();
		$driverList = str_replace(";"," - ",$DList);
		
        $this->paginate = [
            'limit' => $limit,
            'order' => ['Purchases.created' => 'DESC'],
			'contain'=>['Users','Vendors'],
        ];        
        $keyword = $this->request->query('keyword');
		$driverid = $this->request->query('driverid');
		$Status = $this->request->query('status');
		$startDate = $this->request->query('startDate');
		$endDate = $this->request->query('endDate');
		$condition[] = '';
		if($Status != ''){
			$condition[] = ['Purchases.deliveryStatus'=>$Status];
		}
		if($driverid !=''){
			$condition[] = ['Purchases.assignDriver'=>$driverid];
		}
		
		if($startDate != ''){
			$startDate = $startDate." 00:00:01" ;
			$condition[] = ['Purchases.created >='=> $startDate];
        }
        if($endDate != ''){
			$endDate = $endDate." 23:59:59";
			$condition[] = ['Purchases.created <='=> $endDate];
        }
		
        if($keyword != ''){
			$condition = [
				'OR' => [
					["Purchases.shippingName LIKE '%".$keyword."%'"],
					["Purchases.shippingAddress LIKE '%".$keyword."%'"],
					["Purchases.shippingCity LIKE '%".$keyword."%'"],
					["Purchases.shippingState LIKE '%".$keyword."%'"],
					["Purchases.shippingZipcode LIKE '%".$keyword."%'"],
					["Users.fullName LIKE '%".$keyword."%'"],
					["Users.lastName LIKE '%".$keyword."%'"],
					["Users.email LIKE '%".$keyword."%'"],
					["Vendors.fullName LIKE '%".$keyword."%'"],
					["Vendors.lastName LIKE '%".$keyword."%'"],
					["Vendors.email LIKE '%".$keyword."%'"],
				]				
			];
		}        
        $query = $this->Purchases->find('all')->where($condition);       
        $purchases = $this->paginate($query);
        $purchases = $purchases->toArray();
		//pr($purchases);die;
        $this->set(compact('purchases', 'limit','driverList'));
    }

      
    /********************************************************************************
	Function Name: add
	*Type: Public function used as action of the controller
	*Input: No input
	*Author: Raushan Suri
	*Modified By: Raushan Suri
	*Output: Function to add hours.
	*********************************************************************************/
    public function add()
    {
        $layoutTitle = 'QuiQR ::  Add New Purchase';
        $this->set(compact('layoutTitle'));
        $this->viewBuilder()->layout('Admin/admin');
		
		
        $purchases = $this->Purchases->newEntity();        
       
        if ($this->request->is('post')) {
            
			$purchases = $this->Purchases->patchEntity($purchases, $this->request->data, ['validate' => 'customer']);            
			$purchases['created'] = date('Y-m-d H:i:s');
			//$path = WWW_ROOT . 'img/uploads/feature/original/';
			if ($this->Purchases->save($purchases)) {
				$this->Flash->success(__('Purchase added successfully.'));
				return $this->redirect(['action' => 'index']);	
			}else{
				//pr($users);die;
				$this->Flash->error(__('Unable to add new purchase, Please try again later.'));
			}
		}
        $this->set(compact('purchases','client_list'));
    }
    
    
    
    
    /********************************************************************************
	Function Name: edit
	*Type: Public function used as action of the controller
	*Input: Member id
	*Author: Raushan Suri
	*Modified By: Raushan Suri
	*Output: Function to edit hours.
	*********************************************************************************/
    public function edit($id)
    {
        $layoutTitle = 'QuiQR :: Edit Purchase';
        $this->set(compact('layoutTitle'));
        $this->viewBuilder()->layout('Admin/admin');
        $this->loadModel('Products');
		$this->loadModel('Users');
		
		
        $purchases = $this->Purchases->find()->where(['Purchases.id' => $id])->first();//fields name in contain[] with coma
		$det = json_decode($purchases->productDetails);
		$productD = array();
		$i=0;
		foreach($det as $vv){
			$productD[$i] = $this->Products->find()->where(['Products.id'=> $vv->productId])->first();
			$i++;
		}
		
		$latitude 	= $purchases->latitude; 
		$longitude	= $purchases->longitude;
		$driverList = array();
		if($latitude && $longitude){
			$conn = ConnectionManager::get('default');
			$radius = "( 3959 * acos( cos( radians($latitude) ) * cos( radians(latitude) ) * cos( radians(longitude) - radians($longitude))  + sin(radians($latitude ))	* sin( radians(latitude))))";
			$query = "SELECT id, address, fullName, email, profile_picture,device,deviceToken,contactNumber, $radius AS distance FROM users WHERE `role`='Driver' AND `deviceToken` !='' AND `status`=1 HAVING distance < 200 ORDER BY distance LIMIT 0 , 100";
			$stmt = $conn->execute($query);
			$results = $stmt ->fetchAll('assoc');
			$driverList = array();
			if($results){
				foreach($results as $result){
					$driverList[$result['id']] = $result['fullName']." (".$result['email'].")";
				}
			}
		}
		
        if ($this->request->is(['patch', 'post', 'put'])) {
			
			
			$purchases = $this->Purchases->patchEntity($purchases, $this->request->data, ['validate' => 'customer']);
			
			
			$path = WWW_ROOT . 'img/uploads/feature/original/';
			if ($this->Purchases->save($purchases)) {
				
				$this->Flash->success(__('The purchase updated successfully.'));
                return $this->redirect(['action' => 'index']);
			} else {
				
				$this->Flash->error(__('Purchase information could not be saved. Please try again later.'));
			}
        }
        $this->set(compact('purchases','productD','driverList'));
    }
    
    
    /********************************************************************************
	Function Name: delete
	*Type: Public function used as action of the controller
	*Input: Member id
	*Author: Raushan Suri
	*Modified By: Raushan Suri
	*Output: Function to delete hours permanently.
	*********************************************************************************/
    public function delete($id = null)
    {
        $users = $this->Purchases->get($id);
        if ($this->Purchases->delete($users)) {
            $this->Flash->success(__('Purchase has been deleted.'));
        } else {
            $this->Flash->error(__('Purchase could not be deleted. Please, try again.'));
        }
        return $this->redirect(['controller' => 'Purchases', 'action' => 'index']);
    }
    
    
    /********************************************************************************
	Function Name: status
	*Type: Public function used as action of the controller
	*Input: Member id
	*Author: Raushan Suri
	*Modified By: Raushan Suri
	*Output: Function to update hours status.
	*********************************************************************************/
    public function status($id){
		$users = $this->Purchases->get($id);
		$status = '1';
		$msg = 'activated';
		if($users->status == '1'){
			$status = '0';
			$msg = 'deactivated';
		}
		
		$articles = TableRegistry::get('Purchases');
		$query = $articles->query();
		$query->update()
			->set(['status' => $status])
			->where(['id' => $id])
			->execute();
		$this->Flash->success(__('Purchase has been '.$msg.' successfully.'));
		return $this->redirect(['controller' => 'Purchases', 'action' => 'index']);
	}
    
    
    /********************************************************************************
	Function Name: details
	*Type: Public function used as action of the controller
	*Input: Member id
	*Author: Raushan Suri
	*Modified By: Raushan Suri
	*Output: Function to view hours information.
	*********************************************************************************/
    public function details($id){
        $layoutTitle = 'QuiQR ::  Member Details';
        $this->set(compact('layoutTitle'));
        $this->viewBuilder()->layout('Admin/admin');        
		$users = $this->Purchases->find()->where(['Purchases.id' => $id])->contain(['Users','Vendors'])->first();
        if(!empty($users)){
			$this->loadModel('Products');
			$det = json_decode($users->productDetails);
			$productD = array();
			$i=0;
			foreach($det as $vv){
				$productD[$i] = $this->Products->find()->where(['Products.id'=> $vv->productId])->first();
				$i++;
			}
            $this->set(compact('users', 'productD'));
        }else{
            $this->Flash->error(__('Member doesnot exist.'));
            return $this->redirect(['controller' => 'Purchases', 'action' => 'index']);
        }
	}
	
	
}